# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SignonPolicyRulesArgs', 'SignonPolicyRules']

@pulumi.input_type
class SignonPolicyRulesArgs:
    def __init__(__self__, *,
                 policy_id: pulumi.Input[_builtins.str],
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['SignonPolicyRulesRuleArgs']]]] = None):
        """
        The set of arguments for constructing a SignonPolicyRules resource.

        :param pulumi.Input[_builtins.str] policy_id: ID of the policy to manage rules for.
        :param pulumi.Input[Sequence[pulumi.Input['SignonPolicyRulesRuleArgs']]] rules: List of policy rules. Rules are processed in priority order (lowest number = highest priority).
        """
        pulumi.set(__self__, "policy_id", policy_id)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the policy to manage rules for.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "policy_id", value)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SignonPolicyRulesRuleArgs']]]]:
        """
        List of policy rules. Rules are processed in priority order (lowest number = highest priority).
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SignonPolicyRulesRuleArgs']]]]):
        pulumi.set(self, "rules", value)


@pulumi.input_type
class _SignonPolicyRulesState:
    def __init__(__self__, *,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['SignonPolicyRulesRuleArgs']]]] = None):
        """
        Input properties used for looking up and filtering SignonPolicyRules resources.

        :param pulumi.Input[_builtins.str] policy_id: ID of the policy to manage rules for.
        :param pulumi.Input[Sequence[pulumi.Input['SignonPolicyRulesRuleArgs']]] rules: List of policy rules. Rules are processed in priority order (lowest number = highest priority).
        """
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the policy to manage rules for.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_id", value)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SignonPolicyRulesRuleArgs']]]]:
        """
        List of policy rules. Rules are processed in priority order (lowest number = highest priority).
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SignonPolicyRulesRuleArgs']]]]):
        pulumi.set(self, "rules", value)


@pulumi.type_token("okta:app/signonPolicyRules:SignonPolicyRules")
class SignonPolicyRules(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SignonPolicyRulesRuleArgs', 'SignonPolicyRulesRuleArgsDict']]]]] = None,
                 __props__=None):
        """
        ## # app.SignonPolicyRules

        Manages multiple app sign-on policy rules for a single policy. This resource allows you to define all rules for a policy in a single configuration block, ensuring consistent priority ordering and avoiding drift issues.

        > **IMPORTANT:** This resource uses name-first matching to identify and update rules. When migrating from individual `AppSignonPolicyRule` resources, ensure rule names remain consistent to enable safe adoption without data loss.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.app.SignonPolicyRules("example",
            policy_id=example_okta_app_signon_policy["id"],
            rules=[
                {
                    "name": "High Priority Rule",
                    "priority": 1,
                    "factor_mode": "2FA",
                    "re_authentication_frequency": "PT2H",
                    "status": "ACTIVE",
                },
                {
                    "name": "Low Priority Rule",
                    "priority": 2,
                    "factor_mode": "1FA",
                    "access": "ALLOW",
                    "status": "ACTIVE",
                },
                {
                    "name": "Deny Rule",
                    "priority": 3,
                    "access": "DENY",
                    "status": "ACTIVE",
                },
            ])
        ```

        ## Priority Management

        > **IMPORTANT:** When managing priorities, follow Okta's top-down synchronization strategy to avoid automatic priority shifting. Always update rules in priority order (P1 → PN) to prevent cascading shifts.

        ### Priority Behavior

        - Priorities are **0-indexed** but can be any positive integer.
        - When you omit `priority` in config, Terraform will display the actual priority assigned by Okta in the state.
        - Okta allows gaps in priorities (e.g., priorities 1, 2, 5, 99 are valid).
        - **Maximum of 99 rules per policy:** You can define up to 99 custom rules. Priority 99 is reserved for the system Catch-all Rule.
        - If you update multiple rules simultaneously and priorities conflict, Okta may automatically shift priorities to resolve conflicts. To prevent this:
          1. Use explicit, sequential priority values (1, 2, 3, 4, 5).
          2. Avoid updating rules with the same priority.
          3. Consider using temporary high priorities (100+) if reordering is needed.

        ### System Rules and Catch-all Rule

        - **Catch-all Rule:** Every policy includes a system-level Catch-all Rule with priority 99. This is the default rule that applies if no other rules match.
        - **Immutable:** System rules (like "Catch-all Rule") cannot be modified, deleted, or have their conditions/priorities changed.
        - **Import behavior:** If you import a policy with a Catch-all Rule, it will appear in your state but cannot be managed by Terraform. Omit it from your configuration.

        ## Migration from AppSignonPolicyRule

        If you currently use multiple individual `AppSignonPolicyRule` resources, follow these steps to safely migrate to the grouped resource:

        ### Step 1: Backup Your State

        ### Step 2: Identify Rule IDs and Names

        List all rules in your policy to identify their IDs and names:

        ### Step 4: Create the Grouped Resource Configuration

        Create a new `app.SignonPolicyRules` resource with the same rules. Use **rule names as the matching key** (do NOT include `id` unless adopting an existing rule):

        ```python
        import pulumi
        import pulumi_okta as okta

        migrated = okta.app.SignonPolicyRules("migrated",
            policy_id=my_policy["id"],
            rules=[
                {
                    "name": "High Priority Rule",
                    "priority": 1,
                    "factor_mode": "2FA",
                    "re_authentication_frequency": "PT2H",
                    "status": "ACTIVE",
                },
                {
                    "name": "Second Rule",
                    "priority": 2,
                    "factor_mode": "1FA",
                    "status": "ACTIVE",
                },
                {
                    "name": "Deny Rule",
                    "priority": 3,
                    "access": "DENY",
                    "status": "ACTIVE",
                },
            ])
        ```

        ### Step 5: Plan and Verify

        Run `pulumi preview` to see if any changes will be made:

        **Expected outcome:** Either "No changes" or only legitimate config updates. If the plan shows unexpected deletes or recreates:
        - Verify rule names match exactly (case-sensitive).
        - Check that attributes (access, factor_mode, etc.) match Okta's current state.
        - Ensure you're not declaring system rules (e.g., Catch-all Rule).

        ### Step 6: Apply the Migration

        ### Step 6: Verify Final State

        ## Important Migration Notes

        ### Priority Differences

        When migrating from `AppSignonPolicyRule` (single-rule resource) to `app.SignonPolicyRules` (grouped resource):

        - **Old behavior:** Single-rule resource defaults to `priority = 0` in Terraform state, even if Okta assigned a different priority.
        - **New behavior:** Grouped resource reflects the actual priority assigned by Okta. When you omit `priority`, the state will show the real Okta-assigned priority.

        **Action:** Explicitly set `priority` values in your configuration to avoid unexpected changes during migration.

        ### Name-First Matching

        The grouped resource matches rules by **name first**, not by ID:

        - If you rename a rule in config, the provider will match it to the existing rule by the new name.
        - If a name doesn't exist in Okta, a new rule is created.
        - This design prevents accidental re-matching when state order differs from config order.

        ### System Rules

        System rules (e.g., "Catch-all Rule") cannot be managed:

        - If your policy has a system rule, do NOT declare it in your configuration.
        - The provider will detect it during import/read but will not attempt to modify or delete it.
        - System rules are read-only from Terraform's perspective.

        ## Troubleshooting

        ### Plan shows "1 to change" but config matches Okta

        **Cause:** State and config rule order differ, triggering re-matching.

        **Solution:** Verify rule names match exactly (case-sensitive) and attributes are correct. Run `pulumi preview -refresh=true` to refresh state from Okta.

        ### Priorities shift unexpectedly after apply

        **Cause:** Okta automatically shifts priorities when updates conflict. This is expected behavior per Okta's prioritization rules.

        **Solution:** Use explicit, sequential priorities (1, 2, 3, ...) instead of 0-indexed or sparse values. Avoid updating multiple rules simultaneously with overlapping priorities.

        ### Error: "System rule cannot be modified"

        **Cause:** You attempted to set conditions on a system rule (Catch-all Rule).

        **Solution:** Remove the system rule from your configuration. System rules are immutable.

        ## See Also

        - AppSignonPolicy - Create and manage app sign-on policies.
        - [Okta Policy Rule Prioritization Guide](https://developer.okta.com/docs/guides/policy-rule-prioritization/main/) - Learn about priority management and top-down synchronization.

        ## Import

        Import an existing policy's rules:

        ```sh
        $ pulumi import okta:app/signonPolicyRules:SignonPolicyRules example <policy_id>
        ```

        This will populate your state with all rules for the policy (including system rules). Update your configuration to match.


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] policy_id: ID of the policy to manage rules for.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SignonPolicyRulesRuleArgs', 'SignonPolicyRulesRuleArgsDict']]]] rules: List of policy rules. Rules are processed in priority order (lowest number = highest priority).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SignonPolicyRulesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # app.SignonPolicyRules

        Manages multiple app sign-on policy rules for a single policy. This resource allows you to define all rules for a policy in a single configuration block, ensuring consistent priority ordering and avoiding drift issues.

        > **IMPORTANT:** This resource uses name-first matching to identify and update rules. When migrating from individual `AppSignonPolicyRule` resources, ensure rule names remain consistent to enable safe adoption without data loss.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.app.SignonPolicyRules("example",
            policy_id=example_okta_app_signon_policy["id"],
            rules=[
                {
                    "name": "High Priority Rule",
                    "priority": 1,
                    "factor_mode": "2FA",
                    "re_authentication_frequency": "PT2H",
                    "status": "ACTIVE",
                },
                {
                    "name": "Low Priority Rule",
                    "priority": 2,
                    "factor_mode": "1FA",
                    "access": "ALLOW",
                    "status": "ACTIVE",
                },
                {
                    "name": "Deny Rule",
                    "priority": 3,
                    "access": "DENY",
                    "status": "ACTIVE",
                },
            ])
        ```

        ## Priority Management

        > **IMPORTANT:** When managing priorities, follow Okta's top-down synchronization strategy to avoid automatic priority shifting. Always update rules in priority order (P1 → PN) to prevent cascading shifts.

        ### Priority Behavior

        - Priorities are **0-indexed** but can be any positive integer.
        - When you omit `priority` in config, Terraform will display the actual priority assigned by Okta in the state.
        - Okta allows gaps in priorities (e.g., priorities 1, 2, 5, 99 are valid).
        - **Maximum of 99 rules per policy:** You can define up to 99 custom rules. Priority 99 is reserved for the system Catch-all Rule.
        - If you update multiple rules simultaneously and priorities conflict, Okta may automatically shift priorities to resolve conflicts. To prevent this:
          1. Use explicit, sequential priority values (1, 2, 3, 4, 5).
          2. Avoid updating rules with the same priority.
          3. Consider using temporary high priorities (100+) if reordering is needed.

        ### System Rules and Catch-all Rule

        - **Catch-all Rule:** Every policy includes a system-level Catch-all Rule with priority 99. This is the default rule that applies if no other rules match.
        - **Immutable:** System rules (like "Catch-all Rule") cannot be modified, deleted, or have their conditions/priorities changed.
        - **Import behavior:** If you import a policy with a Catch-all Rule, it will appear in your state but cannot be managed by Terraform. Omit it from your configuration.

        ## Migration from AppSignonPolicyRule

        If you currently use multiple individual `AppSignonPolicyRule` resources, follow these steps to safely migrate to the grouped resource:

        ### Step 1: Backup Your State

        ### Step 2: Identify Rule IDs and Names

        List all rules in your policy to identify their IDs and names:

        ### Step 4: Create the Grouped Resource Configuration

        Create a new `app.SignonPolicyRules` resource with the same rules. Use **rule names as the matching key** (do NOT include `id` unless adopting an existing rule):

        ```python
        import pulumi
        import pulumi_okta as okta

        migrated = okta.app.SignonPolicyRules("migrated",
            policy_id=my_policy["id"],
            rules=[
                {
                    "name": "High Priority Rule",
                    "priority": 1,
                    "factor_mode": "2FA",
                    "re_authentication_frequency": "PT2H",
                    "status": "ACTIVE",
                },
                {
                    "name": "Second Rule",
                    "priority": 2,
                    "factor_mode": "1FA",
                    "status": "ACTIVE",
                },
                {
                    "name": "Deny Rule",
                    "priority": 3,
                    "access": "DENY",
                    "status": "ACTIVE",
                },
            ])
        ```

        ### Step 5: Plan and Verify

        Run `pulumi preview` to see if any changes will be made:

        **Expected outcome:** Either "No changes" or only legitimate config updates. If the plan shows unexpected deletes or recreates:
        - Verify rule names match exactly (case-sensitive).
        - Check that attributes (access, factor_mode, etc.) match Okta's current state.
        - Ensure you're not declaring system rules (e.g., Catch-all Rule).

        ### Step 6: Apply the Migration

        ### Step 6: Verify Final State

        ## Important Migration Notes

        ### Priority Differences

        When migrating from `AppSignonPolicyRule` (single-rule resource) to `app.SignonPolicyRules` (grouped resource):

        - **Old behavior:** Single-rule resource defaults to `priority = 0` in Terraform state, even if Okta assigned a different priority.
        - **New behavior:** Grouped resource reflects the actual priority assigned by Okta. When you omit `priority`, the state will show the real Okta-assigned priority.

        **Action:** Explicitly set `priority` values in your configuration to avoid unexpected changes during migration.

        ### Name-First Matching

        The grouped resource matches rules by **name first**, not by ID:

        - If you rename a rule in config, the provider will match it to the existing rule by the new name.
        - If a name doesn't exist in Okta, a new rule is created.
        - This design prevents accidental re-matching when state order differs from config order.

        ### System Rules

        System rules (e.g., "Catch-all Rule") cannot be managed:

        - If your policy has a system rule, do NOT declare it in your configuration.
        - The provider will detect it during import/read but will not attempt to modify or delete it.
        - System rules are read-only from Terraform's perspective.

        ## Troubleshooting

        ### Plan shows "1 to change" but config matches Okta

        **Cause:** State and config rule order differ, triggering re-matching.

        **Solution:** Verify rule names match exactly (case-sensitive) and attributes are correct. Run `pulumi preview -refresh=true` to refresh state from Okta.

        ### Priorities shift unexpectedly after apply

        **Cause:** Okta automatically shifts priorities when updates conflict. This is expected behavior per Okta's prioritization rules.

        **Solution:** Use explicit, sequential priorities (1, 2, 3, ...) instead of 0-indexed or sparse values. Avoid updating multiple rules simultaneously with overlapping priorities.

        ### Error: "System rule cannot be modified"

        **Cause:** You attempted to set conditions on a system rule (Catch-all Rule).

        **Solution:** Remove the system rule from your configuration. System rules are immutable.

        ## See Also

        - AppSignonPolicy - Create and manage app sign-on policies.
        - [Okta Policy Rule Prioritization Guide](https://developer.okta.com/docs/guides/policy-rule-prioritization/main/) - Learn about priority management and top-down synchronization.

        ## Import

        Import an existing policy's rules:

        ```sh
        $ pulumi import okta:app/signonPolicyRules:SignonPolicyRules example <policy_id>
        ```

        This will populate your state with all rules for the policy (including system rules). Update your configuration to match.


        :param str resource_name: The name of the resource.
        :param SignonPolicyRulesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SignonPolicyRulesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SignonPolicyRulesRuleArgs', 'SignonPolicyRulesRuleArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SignonPolicyRulesArgs.__new__(SignonPolicyRulesArgs)

            if policy_id is None and not opts.urn:
                raise TypeError("Missing required property 'policy_id'")
            __props__.__dict__["policy_id"] = policy_id
            __props__.__dict__["rules"] = rules
        super(SignonPolicyRules, __self__).__init__(
            'okta:app/signonPolicyRules:SignonPolicyRules',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SignonPolicyRulesRuleArgs', 'SignonPolicyRulesRuleArgsDict']]]]] = None) -> 'SignonPolicyRules':
        """
        Get an existing SignonPolicyRules resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] policy_id: ID of the policy to manage rules for.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SignonPolicyRulesRuleArgs', 'SignonPolicyRulesRuleArgsDict']]]] rules: List of policy rules. Rules are processed in priority order (lowest number = highest priority).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SignonPolicyRulesState.__new__(_SignonPolicyRulesState)

        __props__.__dict__["policy_id"] = policy_id
        __props__.__dict__["rules"] = rules
        return SignonPolicyRules(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the policy to manage rules for.
        """
        return pulumi.get(self, "policy_id")

    @_builtins.property
    @pulumi.getter
    def rules(self) -> pulumi.Output[Optional[Sequence['outputs.SignonPolicyRulesRule']]]:
        """
        List of policy rules. Rules are processed in priority order (lowest number = highest priority).
        """
        return pulumi.get(self, "rules")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EndUserMyRequestsArgs', 'EndUserMyRequests']

@pulumi.input_type
class EndUserMyRequestsArgs:
    def __init__(__self__, *,
                 entry_id: pulumi.Input[_builtins.str],
                 requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]]] = None):
        """
        The set of arguments for constructing a EndUserMyRequests resource.

        :param pulumi.Input[_builtins.str] entry_id: The ID of the catalog entry for which the request is being made.
        :param pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]] requester_field_values: The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        """
        pulumi.set(__self__, "entry_id", entry_id)
        if requester_field_values is not None:
            pulumi.set(__self__, "requester_field_values", requester_field_values)

    @_builtins.property
    @pulumi.getter(name="entryId")
    def entry_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the catalog entry for which the request is being made.
        """
        return pulumi.get(self, "entry_id")

    @entry_id.setter
    def entry_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "entry_id", value)

    @_builtins.property
    @pulumi.getter(name="requesterFieldValues")
    def requester_field_values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]]]:
        """
        The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        """
        return pulumi.get(self, "requester_field_values")

    @requester_field_values.setter
    def requester_field_values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]]]):
        pulumi.set(self, "requester_field_values", value)


@pulumi.input_type
class _EndUserMyRequestsState:
    def __init__(__self__, *,
                 entry_id: Optional[pulumi.Input[_builtins.str]] = None,
                 requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EndUserMyRequests resources.

        :param pulumi.Input[_builtins.str] entry_id: The ID of the catalog entry for which the request is being made.
        :param pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]] requester_field_values: The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        :param pulumi.Input[_builtins.str] status: The status of the request. Possible values include: `APPROVED`, `CANCELED`, `DENIED`, `EXPIRED`, `PENDING`, `REJECTED`, `SUBMITTED`
        """
        if entry_id is not None:
            pulumi.set(__self__, "entry_id", entry_id)
        if requester_field_values is not None:
            pulumi.set(__self__, "requester_field_values", requester_field_values)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="entryId")
    def entry_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the catalog entry for which the request is being made.
        """
        return pulumi.get(self, "entry_id")

    @entry_id.setter
    def entry_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "entry_id", value)

    @_builtins.property
    @pulumi.getter(name="requesterFieldValues")
    def requester_field_values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]]]:
        """
        The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        """
        return pulumi.get(self, "requester_field_values")

    @requester_field_values.setter
    def requester_field_values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndUserMyRequestsRequesterFieldValueArgs']]]]):
        pulumi.set(self, "requester_field_values", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the request. Possible values include: `APPROVED`, `CANCELED`, `DENIED`, `EXPIRED`, `PENDING`, `REJECTED`, `SUBMITTED`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("okta:index/endUserMyRequests:EndUserMyRequests")
class EndUserMyRequests(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 entry_id: Optional[pulumi.Input[_builtins.str]] = None,
                 requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndUserMyRequestsRequesterFieldValueArgs', 'EndUserMyRequestsRequesterFieldValueArgsDict']]]]] = None,
                 __props__=None):
        """
        Manages an End User Request in Okta Identity Governance. This resource allows you to create access requests on behalf of end users through the Okta Identity Governance system.

        This resource creates access requests with the specified requester field values and tracks the status of the request. The resource does not support updates or deletions - requests must be managed through the Okta Dashboard after creation.

        > **Note:** This resource is part of Okta Identity Governance functionality and requires appropriate licensing and configuration.

        **Important Limitations:**
        - **Update Not Supported**: This resource does not support updates. To modify a request, you must cancel it via the Okta Dashboard and recreate the resource.
        - **Delete Not Supported**: This resource does not support deletions. Requests must be cancelled via the Okta Dashboard.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.EndUserMyRequests("example",
            entry_id="cen123456789abcdefgh",
            requester_field_values=[
                {
                    "id": "abcdefgh-0123-4567-8910-hgfedcba123",
                    "type": "TEXT",
                    "value": "I need access to complete my certification.",
                },
                {
                    "id": "ijklmnop-a12b2-c3d4-e5f6-abcdefghi",
                    "type": "DURATION",
                    "value": "For 5 days",
                },
                {
                    "id": "tuvwxyz-0123-456-8910-zyxwvut0123",
                    "type": "SELECT",
                    "value": "Yes",
                },
            ])
        ```

        ### Example with Multi-Select Values

        ```python
        import pulumi
        import pulumi_okta as okta

        multi_select_example = okta.EndUserMyRequests("multi_select_example",
            entry_id="cen123456789abcdefgh",
            requester_field_values=[
                {
                    "id": "multi-select-field-id",
                    "type": "MULTISELECT",
                    "label": "Select multiple options",
                    "values": [
                        "Option1",
                        "Option2",
                        "Option3",
                    ],
                },
                {
                    "id": "text-field-id",
                    "type": "TEXT",
                    "value": "Additional justification text",
                },
            ])
        ```

        ## Field Type Guidelines

        ### Field Type Usage

        - **TEXT**: Use `value` for free-form text input
        - **SELECT**: Use `value` for single selection from predefined options
        - **MULTISELECT**: Use `values` (list) for multiple selections from predefined options
        - **DURATION**: Use `value` for time duration specifications (e.g., "5 days", "2 weeks")
        - **ISO_DATE**: Use `value` for date specifications in ISO format
        - **OKTA_USER_ID**: Use `value` for Okta user identifiers

        ### Important Notes

        - For `MULTISELECT` type fields, you must use the `values` attribute instead of `value`
        - The `id` field is always required and must match the field ID defined in the approval system
        - The `label` and `type` fields are optional but recommended for clarity
        - Field requirements and validation are determined by the approval system configuration

        ## Limitations and Considerations

        1. **No Updates**: Once created, requests cannot be updated through Terraform. Any changes require cancelling the request via Okta Dashboard and recreating.

        2. **No Deletions**: Requests cannot be deleted through Terraform. Use the Okta Dashboard to cancel requests.

        3. **Field Dependencies**: The required fields and their types are determined by the approval system configuration in Okta Identity Governance.

        4. **Status Tracking**: The `status` field is read-only and reflects the current state of the request in the approval workflow.

        5. **Identity Governance Licensing**: This resource requires Okta Identity Governance licensing and proper configuration.

        ## Import

        ```sh
        $ pulumi import okta:index/endUserMyRequests:EndUserMyRequests example <request_id/entry_id>
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] entry_id: The ID of the catalog entry for which the request is being made.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EndUserMyRequestsRequesterFieldValueArgs', 'EndUserMyRequestsRequesterFieldValueArgsDict']]]] requester_field_values: The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EndUserMyRequestsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an End User Request in Okta Identity Governance. This resource allows you to create access requests on behalf of end users through the Okta Identity Governance system.

        This resource creates access requests with the specified requester field values and tracks the status of the request. The resource does not support updates or deletions - requests must be managed through the Okta Dashboard after creation.

        > **Note:** This resource is part of Okta Identity Governance functionality and requires appropriate licensing and configuration.

        **Important Limitations:**
        - **Update Not Supported**: This resource does not support updates. To modify a request, you must cancel it via the Okta Dashboard and recreate the resource.
        - **Delete Not Supported**: This resource does not support deletions. Requests must be cancelled via the Okta Dashboard.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.EndUserMyRequests("example",
            entry_id="cen123456789abcdefgh",
            requester_field_values=[
                {
                    "id": "abcdefgh-0123-4567-8910-hgfedcba123",
                    "type": "TEXT",
                    "value": "I need access to complete my certification.",
                },
                {
                    "id": "ijklmnop-a12b2-c3d4-e5f6-abcdefghi",
                    "type": "DURATION",
                    "value": "For 5 days",
                },
                {
                    "id": "tuvwxyz-0123-456-8910-zyxwvut0123",
                    "type": "SELECT",
                    "value": "Yes",
                },
            ])
        ```

        ### Example with Multi-Select Values

        ```python
        import pulumi
        import pulumi_okta as okta

        multi_select_example = okta.EndUserMyRequests("multi_select_example",
            entry_id="cen123456789abcdefgh",
            requester_field_values=[
                {
                    "id": "multi-select-field-id",
                    "type": "MULTISELECT",
                    "label": "Select multiple options",
                    "values": [
                        "Option1",
                        "Option2",
                        "Option3",
                    ],
                },
                {
                    "id": "text-field-id",
                    "type": "TEXT",
                    "value": "Additional justification text",
                },
            ])
        ```

        ## Field Type Guidelines

        ### Field Type Usage

        - **TEXT**: Use `value` for free-form text input
        - **SELECT**: Use `value` for single selection from predefined options
        - **MULTISELECT**: Use `values` (list) for multiple selections from predefined options
        - **DURATION**: Use `value` for time duration specifications (e.g., "5 days", "2 weeks")
        - **ISO_DATE**: Use `value` for date specifications in ISO format
        - **OKTA_USER_ID**: Use `value` for Okta user identifiers

        ### Important Notes

        - For `MULTISELECT` type fields, you must use the `values` attribute instead of `value`
        - The `id` field is always required and must match the field ID defined in the approval system
        - The `label` and `type` fields are optional but recommended for clarity
        - Field requirements and validation are determined by the approval system configuration

        ## Limitations and Considerations

        1. **No Updates**: Once created, requests cannot be updated through Terraform. Any changes require cancelling the request via Okta Dashboard and recreating.

        2. **No Deletions**: Requests cannot be deleted through Terraform. Use the Okta Dashboard to cancel requests.

        3. **Field Dependencies**: The required fields and their types are determined by the approval system configuration in Okta Identity Governance.

        4. **Status Tracking**: The `status` field is read-only and reflects the current state of the request in the approval workflow.

        5. **Identity Governance Licensing**: This resource requires Okta Identity Governance licensing and proper configuration.

        ## Import

        ```sh
        $ pulumi import okta:index/endUserMyRequests:EndUserMyRequests example <request_id/entry_id>
        ```


        :param str resource_name: The name of the resource.
        :param EndUserMyRequestsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndUserMyRequestsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 entry_id: Optional[pulumi.Input[_builtins.str]] = None,
                 requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndUserMyRequestsRequesterFieldValueArgs', 'EndUserMyRequestsRequesterFieldValueArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndUserMyRequestsArgs.__new__(EndUserMyRequestsArgs)

            if entry_id is None and not opts.urn:
                raise TypeError("Missing required property 'entry_id'")
            __props__.__dict__["entry_id"] = entry_id
            __props__.__dict__["requester_field_values"] = requester_field_values
            __props__.__dict__["status"] = None
        super(EndUserMyRequests, __self__).__init__(
            'okta:index/endUserMyRequests:EndUserMyRequests',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            entry_id: Optional[pulumi.Input[_builtins.str]] = None,
            requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndUserMyRequestsRequesterFieldValueArgs', 'EndUserMyRequestsRequesterFieldValueArgsDict']]]]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'EndUserMyRequests':
        """
        Get an existing EndUserMyRequests resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] entry_id: The ID of the catalog entry for which the request is being made.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EndUserMyRequestsRequesterFieldValueArgs', 'EndUserMyRequestsRequesterFieldValueArgsDict']]]] requester_field_values: The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        :param pulumi.Input[_builtins.str] status: The status of the request. Possible values include: `APPROVED`, `CANCELED`, `DENIED`, `EXPIRED`, `PENDING`, `REJECTED`, `SUBMITTED`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EndUserMyRequestsState.__new__(_EndUserMyRequestsState)

        __props__.__dict__["entry_id"] = entry_id
        __props__.__dict__["requester_field_values"] = requester_field_values
        __props__.__dict__["status"] = status
        return EndUserMyRequests(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="entryId")
    def entry_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the catalog entry for which the request is being made.
        """
        return pulumi.get(self, "entry_id")

    @_builtins.property
    @pulumi.getter(name="requesterFieldValues")
    def requester_field_values(self) -> pulumi.Output[Optional[Sequence['outputs.EndUserMyRequestsRequesterFieldValue']]]:
        """
        The requester input fields required by the approval system. Note: The fields required are determined by the approval system.
        """
        return pulumi.get(self, "requester_field_values")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the request. Possible values include: `APPROVED`, `CANCELED`, `DENIED`, `EXPIRED`, `PENDING`, `REJECTED`, `SUBMITTED`
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetPushGroupResult',
    'AwaitableGetPushGroupResult',
    'get_push_group',
    'get_push_group_output',
]

@pulumi.output_type
class GetPushGroupResult:
    """
    A collection of values returned by getPushGroup.
    """
    def __init__(__self__, app_id=None, id=None, source_group_id=None, status=None, target_group_id=None):
        if app_id and not isinstance(app_id, str):
            raise TypeError("Expected argument 'app_id' to be a str")
        pulumi.set(__self__, "app_id", app_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if source_group_id and not isinstance(source_group_id, str):
            raise TypeError("Expected argument 'source_group_id' to be a str")
        pulumi.set(__self__, "source_group_id", source_group_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if target_group_id and not isinstance(target_group_id, str):
            raise TypeError("Expected argument 'target_group_id' to be a str")
        pulumi.set(__self__, "target_group_id", target_group_id)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> _builtins.str:
        """
        The ID of the Okta Application.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Push Group ID
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="sourceGroupId")
    def source_group_id(self) -> _builtins.str:
        """
        The ID of the source group in Okta.
        """
        return pulumi.get(self, "source_group_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the push group mapping. Valid values: `ACTIVE` and `INACTIVE`
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="targetGroupId")
    def target_group_id(self) -> _builtins.str:
        """
        The ID of the existing target group for the push group mapping. This is used to link to an existing group
        """
        return pulumi.get(self, "target_group_id")


class AwaitableGetPushGroupResult(GetPushGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPushGroupResult(
            app_id=self.app_id,
            id=self.id,
            source_group_id=self.source_group_id,
            status=self.status,
            target_group_id=self.target_group_id)


def get_push_group(app_id: Optional[_builtins.str] = None,
                   id: Optional[_builtins.str] = None,
                   source_group_id: Optional[_builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPushGroupResult:
    """
    Get a Push Group assignment for an Application in Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    sample = okta.get_push_group(app_id="<okta_app_id>",
        id="<push_group_mapping_id>")
    another_sample = okta.get_push_group(app_id="<okta_app_id>",
        source_group_id="<okta_source_group_id>")
    ```


    :param _builtins.str app_id: The ID of the Okta Application.
    :param _builtins.str id: Push Group ID
    :param _builtins.str source_group_id: The ID of the source group in Okta.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    __args__['id'] = id
    __args__['sourceGroupId'] = source_group_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getPushGroup:getPushGroup', __args__, opts=opts, typ=GetPushGroupResult).value

    return AwaitableGetPushGroupResult(
        app_id=pulumi.get(__ret__, 'app_id'),
        id=pulumi.get(__ret__, 'id'),
        source_group_id=pulumi.get(__ret__, 'source_group_id'),
        status=pulumi.get(__ret__, 'status'),
        target_group_id=pulumi.get(__ret__, 'target_group_id'))
def get_push_group_output(app_id: Optional[pulumi.Input[_builtins.str]] = None,
                          id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          source_group_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPushGroupResult]:
    """
    Get a Push Group assignment for an Application in Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    sample = okta.get_push_group(app_id="<okta_app_id>",
        id="<push_group_mapping_id>")
    another_sample = okta.get_push_group(app_id="<okta_app_id>",
        source_group_id="<okta_source_group_id>")
    ```


    :param _builtins.str app_id: The ID of the Okta Application.
    :param _builtins.str id: Push Group ID
    :param _builtins.str source_group_id: The ID of the source group in Okta.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    __args__['id'] = id
    __args__['sourceGroupId'] = source_group_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getPushGroup:getPushGroup', __args__, opts=opts, typ=GetPushGroupResult)
    return __ret__.apply(lambda __response__: GetPushGroupResult(
        app_id=pulumi.get(__response__, 'app_id'),
        id=pulumi.get(__response__, 'id'),
        source_group_id=pulumi.get(__response__, 'source_group_id'),
        status=pulumi.get(__response__, 'status'),
        target_group_id=pulumi.get(__response__, 'target_group_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetFederatedClaimResult',
    'AwaitableGetFederatedClaimResult',
    'get_federated_claim',
    'get_federated_claim_output',
]

@pulumi.output_type
class GetFederatedClaimResult:
    """
    A collection of values returned by getFederatedClaim.
    """
    def __init__(__self__, app_id=None, expression=None, id=None, name=None):
        if app_id and not isinstance(app_id, str):
            raise TypeError("Expected argument 'app_id' to be a str")
        pulumi.set(__self__, "app_id", app_id)
        if expression and not isinstance(expression, str):
            raise TypeError("Expected argument 'expression' to be a str")
        pulumi.set(__self__, "expression", expression)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> _builtins.str:
        """
        The ID of the application that the federated claim belongs to.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def expression(self) -> _builtins.str:
        """
        The Okta Expression Language expression to be evaluated at runtime.
        """
        return pulumi.get(self, "expression")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier for the federated claim.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the claim to be used in the produced token.
        """
        return pulumi.get(self, "name")


class AwaitableGetFederatedClaimResult(GetFederatedClaimResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFederatedClaimResult(
            app_id=self.app_id,
            expression=self.expression,
            id=self.id,
            name=self.name)


def get_federated_claim(app_id: Optional[_builtins.str] = None,
                        id: Optional[_builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFederatedClaimResult:
    """
    Get a federated claim for an Okta application.

    Use this data source to retrieve information about a federated claim that has been configured for an application. Federated claims add custom claims to tokens produced for an application using Okta Expression Language.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.app.get_federated_claim(app_id="0oa1234567890abcdef",
        id="ofcu234567890abcdef")
    pulumi.export("claimExpression", example.expression)
    ```

    ### Using with a Resource

    ```python
    import pulumi
    import pulumi_okta as okta

    test_app = okta.app.Saml("test_app",
        label="example",
        sso_url="https://example.com",
        recipient="https://example.com",
        destination="https://example.com",
        audience="https://example.com/audience",
        subject_name_id_template="${user.userName}",
        subject_name_id_format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
        response_signed=True,
        signature_algorithm="RSA_SHA256",
        digest_algorithm="SHA256")
    example_federated_claim = okta.app.FederatedClaim("example",
        app_id=test_app.id,
        name="role_last_name",
        expression="user.profile.lastName")
    example = okta.app.get_federated_claim_output(app_id=test_app.id,
        id=example_federated_claim.id)
    pulumi.export("claimName", example.name)
    pulumi.export("claimExpression", example.expression)
    ```


    :param _builtins.str app_id: The ID of the application that the federated claim belongs to.
    :param _builtins.str id: The unique identifier for the federated claim.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:app/getFederatedClaim:getFederatedClaim', __args__, opts=opts, typ=GetFederatedClaimResult).value

    return AwaitableGetFederatedClaimResult(
        app_id=pulumi.get(__ret__, 'app_id'),
        expression=pulumi.get(__ret__, 'expression'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))
def get_federated_claim_output(app_id: Optional[pulumi.Input[_builtins.str]] = None,
                               id: Optional[pulumi.Input[_builtins.str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFederatedClaimResult]:
    """
    Get a federated claim for an Okta application.

    Use this data source to retrieve information about a federated claim that has been configured for an application. Federated claims add custom claims to tokens produced for an application using Okta Expression Language.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.app.get_federated_claim(app_id="0oa1234567890abcdef",
        id="ofcu234567890abcdef")
    pulumi.export("claimExpression", example.expression)
    ```

    ### Using with a Resource

    ```python
    import pulumi
    import pulumi_okta as okta

    test_app = okta.app.Saml("test_app",
        label="example",
        sso_url="https://example.com",
        recipient="https://example.com",
        destination="https://example.com",
        audience="https://example.com/audience",
        subject_name_id_template="${user.userName}",
        subject_name_id_format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
        response_signed=True,
        signature_algorithm="RSA_SHA256",
        digest_algorithm="SHA256")
    example_federated_claim = okta.app.FederatedClaim("example",
        app_id=test_app.id,
        name="role_last_name",
        expression="user.profile.lastName")
    example = okta.app.get_federated_claim_output(app_id=test_app.id,
        id=example_federated_claim.id)
    pulumi.export("claimName", example.name)
    pulumi.export("claimExpression", example.expression)
    ```


    :param _builtins.str app_id: The ID of the application that the federated claim belongs to.
    :param _builtins.str id: The unique identifier for the federated claim.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:app/getFederatedClaim:getFederatedClaim', __args__, opts=opts, typ=GetFederatedClaimResult)
    return __ret__.apply(lambda __response__: GetFederatedClaimResult(
        app_id=pulumi.get(__response__, 'app_id'),
        expression=pulumi.get(__response__, 'expression'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['RealmAssignmentArgs', 'RealmAssignment']

@pulumi.input_type
class RealmAssignmentArgs:
    def __init__(__self__, *,
                 profile_source_id: pulumi.Input[_builtins.str],
                 realm_id: pulumi.Input[_builtins.str],
                 condition_expression: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a RealmAssignment resource.

        :param pulumi.Input[_builtins.str] profile_source_id: The ID of the Profile Source.
        :param pulumi.Input[_builtins.str] realm_id: The ID of the Realm asscociated with the Realm Assignment.
        :param pulumi.Input[_builtins.str] condition_expression: Condition expression for the Realm Assignment in Okta Expression Language. Example: `user.profile.role =="Manager"` or `user.profile.state.contains("example")`.
        :param pulumi.Input[_builtins.str] name: The name of the Okta Realm Assignment.
        :param pulumi.Input[_builtins.int] priority: The Priority of the Realm Assignment. The lower the number, the higher the priority.
        :param pulumi.Input[_builtins.str] status: Defines whether the Realm Assignment is active or not. Valid values: `ACTIVE` and `INACTIVE`.
        """
        pulumi.set(__self__, "profile_source_id", profile_source_id)
        pulumi.set(__self__, "realm_id", realm_id)
        if condition_expression is not None:
            pulumi.set(__self__, "condition_expression", condition_expression)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="profileSourceId")
    def profile_source_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Profile Source.
        """
        return pulumi.get(self, "profile_source_id")

    @profile_source_id.setter
    def profile_source_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "profile_source_id", value)

    @_builtins.property
    @pulumi.getter(name="realmId")
    def realm_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Realm asscociated with the Realm Assignment.
        """
        return pulumi.get(self, "realm_id")

    @realm_id.setter
    def realm_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "realm_id", value)

    @_builtins.property
    @pulumi.getter(name="conditionExpression")
    def condition_expression(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Condition expression for the Realm Assignment in Okta Expression Language. Example: `user.profile.role =="Manager"` or `user.profile.state.contains("example")`.
        """
        return pulumi.get(self, "condition_expression")

    @condition_expression.setter
    def condition_expression(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_expression", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Okta Realm Assignment.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The Priority of the Realm Assignment. The lower the number, the higher the priority.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Defines whether the Realm Assignment is active or not. Valid values: `ACTIVE` and `INACTIVE`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _RealmAssignmentState:
    def __init__(__self__, *,
                 condition_expression: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 profile_source_id: Optional[pulumi.Input[_builtins.str]] = None,
                 realm_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RealmAssignment resources.

        :param pulumi.Input[_builtins.str] condition_expression: Condition expression for the Realm Assignment in Okta Expression Language. Example: `user.profile.role =="Manager"` or `user.profile.state.contains("example")`.
        :param pulumi.Input[_builtins.bool] is_default: Indicates whether the realm assignment is the default.
        :param pulumi.Input[_builtins.str] name: The name of the Okta Realm Assignment.
        :param pulumi.Input[_builtins.int] priority: The Priority of the Realm Assignment. The lower the number, the higher the priority.
        :param pulumi.Input[_builtins.str] profile_source_id: The ID of the Profile Source.
        :param pulumi.Input[_builtins.str] realm_id: The ID of the Realm asscociated with the Realm Assignment.
        :param pulumi.Input[_builtins.str] status: Defines whether the Realm Assignment is active or not. Valid values: `ACTIVE` and `INACTIVE`.
        """
        if condition_expression is not None:
            pulumi.set(__self__, "condition_expression", condition_expression)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if profile_source_id is not None:
            pulumi.set(__self__, "profile_source_id", profile_source_id)
        if realm_id is not None:
            pulumi.set(__self__, "realm_id", realm_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="conditionExpression")
    def condition_expression(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Condition expression for the Realm Assignment in Okta Expression Language. Example: `user.profile.role =="Manager"` or `user.profile.state.contains("example")`.
        """
        return pulumi.get(self, "condition_expression")

    @condition_expression.setter
    def condition_expression(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_expression", value)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the realm assignment is the default.
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Okta Realm Assignment.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The Priority of the Realm Assignment. The lower the number, the higher the priority.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter(name="profileSourceId")
    def profile_source_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Profile Source.
        """
        return pulumi.get(self, "profile_source_id")

    @profile_source_id.setter
    def profile_source_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "profile_source_id", value)

    @_builtins.property
    @pulumi.getter(name="realmId")
    def realm_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Realm asscociated with the Realm Assignment.
        """
        return pulumi.get(self, "realm_id")

    @realm_id.setter
    def realm_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "realm_id", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Defines whether the Realm Assignment is active or not. Valid values: `ACTIVE` and `INACTIVE`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("okta:index/realmAssignment:RealmAssignment")
class RealmAssignment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 condition_expression: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 profile_source_id: Optional[pulumi.Input[_builtins.str]] = None,
                 realm_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates an Okta Realm Assignment. This resource allows you to create and configure an Okta Realm Assignment.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Realm("example",
            name="Example Realm",
            realm_type="DEFAULT")
        test = okta.RealmAssignment("test",
            name="Example Realm Assignment",
            priority=55,
            status="ACTIVE",
            profile_source_id=test_okta_idp_saml["id"],
            condition_expression="user.profile.login.contains(\\"@example.com\\")",
            realm_id=example.id)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/realmAssignment:RealmAssignment example <realm_assignment_id>
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] condition_expression: Condition expression for the Realm Assignment in Okta Expression Language. Example: `user.profile.role =="Manager"` or `user.profile.state.contains("example")`.
        :param pulumi.Input[_builtins.str] name: The name of the Okta Realm Assignment.
        :param pulumi.Input[_builtins.int] priority: The Priority of the Realm Assignment. The lower the number, the higher the priority.
        :param pulumi.Input[_builtins.str] profile_source_id: The ID of the Profile Source.
        :param pulumi.Input[_builtins.str] realm_id: The ID of the Realm asscociated with the Realm Assignment.
        :param pulumi.Input[_builtins.str] status: Defines whether the Realm Assignment is active or not. Valid values: `ACTIVE` and `INACTIVE`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RealmAssignmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an Okta Realm Assignment. This resource allows you to create and configure an Okta Realm Assignment.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Realm("example",
            name="Example Realm",
            realm_type="DEFAULT")
        test = okta.RealmAssignment("test",
            name="Example Realm Assignment",
            priority=55,
            status="ACTIVE",
            profile_source_id=test_okta_idp_saml["id"],
            condition_expression="user.profile.login.contains(\\"@example.com\\")",
            realm_id=example.id)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/realmAssignment:RealmAssignment example <realm_assignment_id>
        ```


        :param str resource_name: The name of the resource.
        :param RealmAssignmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RealmAssignmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 condition_expression: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 profile_source_id: Optional[pulumi.Input[_builtins.str]] = None,
                 realm_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RealmAssignmentArgs.__new__(RealmAssignmentArgs)

            __props__.__dict__["condition_expression"] = condition_expression
            __props__.__dict__["name"] = name
            __props__.__dict__["priority"] = priority
            if profile_source_id is None and not opts.urn:
                raise TypeError("Missing required property 'profile_source_id'")
            __props__.__dict__["profile_source_id"] = profile_source_id
            if realm_id is None and not opts.urn:
                raise TypeError("Missing required property 'realm_id'")
            __props__.__dict__["realm_id"] = realm_id
            __props__.__dict__["status"] = status
            __props__.__dict__["is_default"] = None
        super(RealmAssignment, __self__).__init__(
            'okta:index/realmAssignment:RealmAssignment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            condition_expression: Optional[pulumi.Input[_builtins.str]] = None,
            is_default: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            priority: Optional[pulumi.Input[_builtins.int]] = None,
            profile_source_id: Optional[pulumi.Input[_builtins.str]] = None,
            realm_id: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'RealmAssignment':
        """
        Get an existing RealmAssignment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] condition_expression: Condition expression for the Realm Assignment in Okta Expression Language. Example: `user.profile.role =="Manager"` or `user.profile.state.contains("example")`.
        :param pulumi.Input[_builtins.bool] is_default: Indicates whether the realm assignment is the default.
        :param pulumi.Input[_builtins.str] name: The name of the Okta Realm Assignment.
        :param pulumi.Input[_builtins.int] priority: The Priority of the Realm Assignment. The lower the number, the higher the priority.
        :param pulumi.Input[_builtins.str] profile_source_id: The ID of the Profile Source.
        :param pulumi.Input[_builtins.str] realm_id: The ID of the Realm asscociated with the Realm Assignment.
        :param pulumi.Input[_builtins.str] status: Defines whether the Realm Assignment is active or not. Valid values: `ACTIVE` and `INACTIVE`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RealmAssignmentState.__new__(_RealmAssignmentState)

        __props__.__dict__["condition_expression"] = condition_expression
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["name"] = name
        __props__.__dict__["priority"] = priority
        __props__.__dict__["profile_source_id"] = profile_source_id
        __props__.__dict__["realm_id"] = realm_id
        __props__.__dict__["status"] = status
        return RealmAssignment(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="conditionExpression")
    def condition_expression(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Condition expression for the Realm Assignment in Okta Expression Language. Example: `user.profile.role =="Manager"` or `user.profile.state.contains("example")`.
        """
        return pulumi.get(self, "condition_expression")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the realm assignment is the default.
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Okta Realm Assignment.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> pulumi.Output[_builtins.int]:
        """
        The Priority of the Realm Assignment. The lower the number, the higher the priority.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter(name="profileSourceId")
    def profile_source_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Profile Source.
        """
        return pulumi.get(self, "profile_source_id")

    @_builtins.property
    @pulumi.getter(name="realmId")
    def realm_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Realm asscociated with the Realm Assignment.
        """
        return pulumi.get(self, "realm_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Defines whether the Realm Assignment is active or not. Valid values: `ACTIVE` and `INACTIVE`.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetPushGroupsResult',
    'AwaitableGetPushGroupsResult',
    'get_push_groups',
    'get_push_groups_output',
]

@pulumi.output_type
class GetPushGroupsResult:
    """
    A collection of values returned by getPushGroups.
    """
    def __init__(__self__, app_id=None, id=None, mappings=None):
        if app_id and not isinstance(app_id, str):
            raise TypeError("Expected argument 'app_id' to be a str")
        pulumi.set(__self__, "app_id", app_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if mappings and not isinstance(mappings, list):
            raise TypeError("Expected argument 'mappings' to be a list")
        pulumi.set(__self__, "mappings", mappings)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> _builtins.str:
        """
        The ID of the Okta Application.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def mappings(self) -> Sequence['outputs.GetPushGroupsMappingResult']:
        """
        List of Push Group mappings for the Application.
        """
        return pulumi.get(self, "mappings")


class AwaitableGetPushGroupsResult(GetPushGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPushGroupsResult(
            app_id=self.app_id,
            id=self.id,
            mappings=self.mappings)


def get_push_groups(app_id: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPushGroupsResult:
    """
    Gets a list of Push Group mappings for an Application in Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    sample = okta.get_push_groups(app_id="<okta_app_id>")
    pulumi.export("sample", sample.mappings)
    ```


    :param _builtins.str app_id: The ID of the Okta Application.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getPushGroups:getPushGroups', __args__, opts=opts, typ=GetPushGroupsResult).value

    return AwaitableGetPushGroupsResult(
        app_id=pulumi.get(__ret__, 'app_id'),
        id=pulumi.get(__ret__, 'id'),
        mappings=pulumi.get(__ret__, 'mappings'))
def get_push_groups_output(app_id: Optional[pulumi.Input[_builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPushGroupsResult]:
    """
    Gets a list of Push Group mappings for an Application in Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    sample = okta.get_push_groups(app_id="<okta_app_id>")
    pulumi.export("sample", sample.mappings)
    ```


    :param _builtins.str app_id: The ID of the Okta Application.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getPushGroups:getPushGroups', __args__, opts=opts, typ=GetPushGroupsResult)
    return __ret__.apply(lambda __response__: GetPushGroupsResult(
        app_id=pulumi.get(__response__, 'app_id'),
        id=pulumi.get(__response__, 'id'),
        mappings=pulumi.get(__response__, 'mappings')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[_builtins.str],
                 user_id: pulumi.Input[_builtins.str],
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 profile: Optional[pulumi.Input[_builtins.str]] = None,
                 retain_assignment: Optional[pulumi.Input[_builtins.bool]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a User resource.

        :param pulumi.Input[_builtins.str] app_id: App to associate user with
        :param pulumi.Input[_builtins.str] user_id: User associated with the application
        :param pulumi.Input[_builtins.str] password: The password to use.
        :param pulumi.Input[_builtins.str] profile: The JSON profile of the App User.
        :param pulumi.Input[_builtins.bool] retain_assignment: Retain the user assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        :param pulumi.Input[_builtins.str] username: The username to use for the app user. In case the user is assigned to the app with `SHARED_USERNAME_AND_PASSWORD` credentials scheme, this field will be computed and should not be set.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "user_id", user_id)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if profile is not None:
            pulumi.set(__self__, "profile", profile)
        if retain_assignment is not None:
            pulumi.set(__self__, "retain_assignment", retain_assignment)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[_builtins.str]:
        """
        App to associate user with
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[_builtins.str]:
        """
        User associated with the application
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "user_id", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The password to use.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def profile(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The JSON profile of the App User.
        """
        return pulumi.get(self, "profile")

    @profile.setter
    def profile(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "profile", value)

    @_builtins.property
    @pulumi.getter(name="retainAssignment")
    def retain_assignment(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Retain the user assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        return pulumi.get(self, "retain_assignment")

    @retain_assignment.setter
    def retain_assignment(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "retain_assignment", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The username to use for the app user. In case the user is assigned to the app with `SHARED_USERNAME_AND_PASSWORD` credentials scheme, this field will be computed and should not be set.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 has_shared_username: Optional[pulumi.Input[_builtins.bool]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 profile: Optional[pulumi.Input[_builtins.str]] = None,
                 retain_assignment: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering User resources.

        :param pulumi.Input[_builtins.str] app_id: App to associate user with
        :param pulumi.Input[_builtins.str] password: The password to use.
        :param pulumi.Input[_builtins.str] profile: The JSON profile of the App User.
        :param pulumi.Input[_builtins.bool] retain_assignment: Retain the user assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        :param pulumi.Input[_builtins.str] user_id: User associated with the application
        :param pulumi.Input[_builtins.str] username: The username to use for the app user. In case the user is assigned to the app with `SHARED_USERNAME_AND_PASSWORD` credentials scheme, this field will be computed and should not be set.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if has_shared_username is not None:
            pulumi.set(__self__, "has_shared_username", has_shared_username)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if profile is not None:
            pulumi.set(__self__, "profile", profile)
        if retain_assignment is not None:
            pulumi.set(__self__, "retain_assignment", retain_assignment)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        App to associate user with
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter(name="hasSharedUsername")
    def has_shared_username(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "has_shared_username")

    @has_shared_username.setter
    def has_shared_username(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "has_shared_username", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The password to use.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def profile(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The JSON profile of the App User.
        """
        return pulumi.get(self, "profile")

    @profile.setter
    def profile(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "profile", value)

    @_builtins.property
    @pulumi.getter(name="retainAssignment")
    def retain_assignment(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Retain the user assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        return pulumi.get(self, "retain_assignment")

    @retain_assignment.setter
    def retain_assignment(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "retain_assignment", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User associated with the application
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The username to use for the app user. In case the user is assigned to the app with `SHARED_USERNAME_AND_PASSWORD` credentials scheme, this field will be computed and should not be set.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.type_token("okta:app/user:User")
class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 profile: Optional[pulumi.Input[_builtins.str]] = None,
                 retain_assignment: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates an Application User.
        		This resource allows you to create and configure an Application User.
        		> **IMPORTANT:** When the 'okta_app_user' is retained, by setting 'retain_assignment' to 'true', it is no longer managed by Terraform after it is destroyed. To truly delete the assignment, you will need to remove it either through the Okta Console or API. This argument exists for the use case where the same user is assigned in multiple places in order to prevent a single destruction removing all of them.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.app.User("example",
            app_id="<app_id>",
            user_id="<user id>",
            username="example")
        ```

        ## Import

        ```sh
        $ pulumi import okta:app/user:User example <app_id>/<user_id>
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: App to associate user with
        :param pulumi.Input[_builtins.str] password: The password to use.
        :param pulumi.Input[_builtins.str] profile: The JSON profile of the App User.
        :param pulumi.Input[_builtins.bool] retain_assignment: Retain the user assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        :param pulumi.Input[_builtins.str] user_id: User associated with the application
        :param pulumi.Input[_builtins.str] username: The username to use for the app user. In case the user is assigned to the app with `SHARED_USERNAME_AND_PASSWORD` credentials scheme, this field will be computed and should not be set.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an Application User.
        		This resource allows you to create and configure an Application User.
        		> **IMPORTANT:** When the 'okta_app_user' is retained, by setting 'retain_assignment' to 'true', it is no longer managed by Terraform after it is destroyed. To truly delete the assignment, you will need to remove it either through the Okta Console or API. This argument exists for the use case where the same user is assigned in multiple places in order to prevent a single destruction removing all of them.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.app.User("example",
            app_id="<app_id>",
            user_id="<user id>",
            username="example")
        ```

        ## Import

        ```sh
        $ pulumi import okta:app/user:User example <app_id>/<user_id>
        ```


        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 profile: Optional[pulumi.Input[_builtins.str]] = None,
                 retain_assignment: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["profile"] = profile
            __props__.__dict__["retain_assignment"] = retain_assignment
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["username"] = username
            __props__.__dict__["has_shared_username"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(User, __self__).__init__(
            'okta:app/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[_builtins.str]] = None,
            has_shared_username: Optional[pulumi.Input[_builtins.bool]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            profile: Optional[pulumi.Input[_builtins.str]] = None,
            retain_assignment: Optional[pulumi.Input[_builtins.bool]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None,
            username: Optional[pulumi.Input[_builtins.str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: App to associate user with
        :param pulumi.Input[_builtins.str] password: The password to use.
        :param pulumi.Input[_builtins.str] profile: The JSON profile of the App User.
        :param pulumi.Input[_builtins.bool] retain_assignment: Retain the user assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        :param pulumi.Input[_builtins.str] user_id: User associated with the application
        :param pulumi.Input[_builtins.str] username: The username to use for the app user. In case the user is assigned to the app with `SHARED_USERNAME_AND_PASSWORD` credentials scheme, this field will be computed and should not be set.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["has_shared_username"] = has_shared_username
        __props__.__dict__["password"] = password
        __props__.__dict__["profile"] = profile
        __props__.__dict__["retain_assignment"] = retain_assignment
        __props__.__dict__["user_id"] = user_id
        __props__.__dict__["username"] = username
        return User(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[_builtins.str]:
        """
        App to associate user with
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter(name="hasSharedUsername")
    def has_shared_username(self) -> pulumi.Output[_builtins.bool]:
        return pulumi.get(self, "has_shared_username")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The password to use.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def profile(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The JSON profile of the App User.
        """
        return pulumi.get(self, "profile")

    @_builtins.property
    @pulumi.getter(name="retainAssignment")
    def retain_assignment(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Retain the user assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        return pulumi.get(self, "retain_assignment")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[_builtins.str]:
        """
        User associated with the application
        """
        return pulumi.get(self, "user_id")

    @_builtins.property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The username to use for the app user. In case the user is assigned to the app with `SHARED_USERNAME_AND_PASSWORD` credentials scheme, this field will be computed and should not be set.
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SamlKeyArgs', 'SamlKey']

@pulumi.input_type
class SamlKeyArgs:
    def __init__(__self__, *,
                 x5cs: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        """
        The set of arguments for constructing a SamlKey resource.

        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] x5cs: base64-encoded X.509 certificate chain with DER encoding
        """
        pulumi.set(__self__, "x5cs", x5cs)

    @_builtins.property
    @pulumi.getter
    def x5cs(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        base64-encoded X.509 certificate chain with DER encoding
        """
        return pulumi.get(self, "x5cs")

    @x5cs.setter
    def x5cs(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "x5cs", value)


@pulumi.input_type
class _SamlKeyState:
    def __init__(__self__, *,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 kid: Optional[pulumi.Input[_builtins.str]] = None,
                 kty: Optional[pulumi.Input[_builtins.str]] = None,
                 use: Optional[pulumi.Input[_builtins.str]] = None,
                 x5cs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 x5t_s256: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SamlKey resources.

        :param pulumi.Input[_builtins.str] created: Date created.
        :param pulumi.Input[_builtins.str] expires_at: Date the cert expires.
        :param pulumi.Input[_builtins.str] kid: Key ID.
        :param pulumi.Input[_builtins.str] kty: Identifies the cryptographic algorithm family used with the key.
        :param pulumi.Input[_builtins.str] use: Intended use of the public key.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] x5cs: base64-encoded X.509 certificate chain with DER encoding
        :param pulumi.Input[_builtins.str] x5t_s256: base64url-encoded SHA-256 thumbprint of the DER encoding of an X.509 certificate.
        """
        if created is not None:
            pulumi.set(__self__, "created", created)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if kid is not None:
            pulumi.set(__self__, "kid", kid)
        if kty is not None:
            pulumi.set(__self__, "kty", kty)
        if use is not None:
            pulumi.set(__self__, "use", use)
        if x5cs is not None:
            pulumi.set(__self__, "x5cs", x5cs)
        if x5t_s256 is not None:
            pulumi.set(__self__, "x5t_s256", x5t_s256)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Date created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Date the cert expires.
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @_builtins.property
    @pulumi.getter
    def kid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Key ID.
        """
        return pulumi.get(self, "kid")

    @kid.setter
    def kid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "kid", value)

    @_builtins.property
    @pulumi.getter
    def kty(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifies the cryptographic algorithm family used with the key.
        """
        return pulumi.get(self, "kty")

    @kty.setter
    def kty(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "kty", value)

    @_builtins.property
    @pulumi.getter
    def use(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Intended use of the public key.
        """
        return pulumi.get(self, "use")

    @use.setter
    def use(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "use", value)

    @_builtins.property
    @pulumi.getter
    def x5cs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        base64-encoded X.509 certificate chain with DER encoding
        """
        return pulumi.get(self, "x5cs")

    @x5cs.setter
    def x5cs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "x5cs", value)

    @_builtins.property
    @pulumi.getter(name="x5tS256")
    def x5t_s256(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        base64url-encoded SHA-256 thumbprint of the DER encoding of an X.509 certificate.
        """
        return pulumi.get(self, "x5t_s256")

    @x5t_s256.setter
    def x5t_s256(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "x5t_s256", value)


@pulumi.type_token("okta:idp/samlKey:SamlKey")
class SamlKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 x5cs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        This resource allows you to create and configure a SAML Identity Provider Signing Key.

        Identity Provider Signing Key can not be updated, it can only be created or removed. Thus, in situation
        where Identity Provider Signing Key should be updated, one can not simply change `x5c` and apply the changes.
        This will cause the error, because the key can not be removed if it's used by the provider. To avoid this situation,
        the behavior of the resource update process is as follows:

        - create a new identity provider key
        - list all identity providers that are using the old key (**even the ones that are managed outside terraform!**)
        - assign a new key to these identity providers
        - remove old identity provider key

        For more details, please refer to the original issue.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example1 = okta.idp.SamlKey("example_1", x5cs=[example["certificate"]])
        example2 = okta.idp.SamlKey("example_2", x5cs=[\"\"\"MIIDnjCCAoagAwIBAgIGAVG3MN+PMA0GCSqGSIb3DQEBBQUAMIGPMQswCQYDVQQGEwJVUzETMBEGA1UECAwKQ2FsaWZvcm5p
        YTEWMBQGA1UEBwwNU2FuIEZyYW5jaXNjbzENMAsGA1UECgwET2t0YTEUMBIGA1UECwwLU1NPUHJvdmlkZXIxEDAOBgNVBAMM
        B2V4YW1wbGUxHDAaBgkqhkiG9w0BCQEWDWluZm9Ab2t0YS5jb20wHhcNMTUxMjE4MjIyMjMyWhcNMjUxMjE4MjIyMzMyWjCB
        jzELMAkGA1UEBhMCVVMxEzARBgNVBAgMCkNhbGlmb3JuaWExFjAUBgNVBAcMDVNhbiBGcmFuY2lzY28xDTALBgNVBAoMBE9r
        dGExFDASBgNVBAsMC1NTT1Byb3ZpZGVyMRAwDgYDVQQDDAdleGFtcGxlMRwwGgYJKoZIhvcNAQkBFg1pbmZvQG9rdGEuY29t
        MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtcnyvuVCrsFEKCwHDenS3Ocjed8eWDv3zLtD2K/iZfE8BMj2wpTf
        n6Ry8zCYey3mWlKdxIybnV9amrujGRnE0ab6Q16v9D6RlFQLOG6dwqoRKuZy33Uyg8PGdEudZjGbWuKCqqXEp+UKALJHV+k4
        wWeVH8g5d1n3KyR2TVajVJpCrPhLFmq1Il4G/IUnPe4MvjXqB6CpKkog1+ThWsItPRJPAM+RweFHXq7KfChXsYE7Mmfuly8s
        DQlvBmQyxZnFHVuiPfCvGHJjpvHy11YlHdOjfgqHRvZbmo30+y0X/oY/yV4YEJ00LL6eJWU4wi7ViY3HP6/VCdRjHoRdr5L/
        DwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCzzhOFkvyYLNFj2WDcq1YqD4sBy1iCia9QpRH3rjQvMKDwQDYWbi6EdOX0TQ/I
        YR7UWGj+2pXd6v0t33lYtoKocp/4lUvT3tfBnWZ5KnObi+J2uY2teUqoYkASN7F+GRPVOuMVoVgm05ss8tuMb2dLc9vsx93s
        Dt+XlMTv/2qi5VPwaDtqduKkzwW9lUfn4xIMkTiVvCpe0X2HneD2Bpuao3/U8Rk0uiPfq6TooWaoW3kjsmErhEAs9bA7xuqo
        1KKY9CdHcFhkSsMhoeaZylZHtzbnoipUlQKSLMdJQiiYZQ0bYL83/Ta9fulr1EERICMFt3GUmtYaZZKHpWSfdJp9\"\"\"])
        ```

        ## Import

        ```sh
        $ pulumi import okta:idp/samlKey:SamlKey example <key_id>
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] x5cs: base64-encoded X.509 certificate chain with DER encoding
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SamlKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to create and configure a SAML Identity Provider Signing Key.

        Identity Provider Signing Key can not be updated, it can only be created or removed. Thus, in situation
        where Identity Provider Signing Key should be updated, one can not simply change `x5c` and apply the changes.
        This will cause the error, because the key can not be removed if it's used by the provider. To avoid this situation,
        the behavior of the resource update process is as follows:

        - create a new identity provider key
        - list all identity providers that are using the old key (**even the ones that are managed outside terraform!**)
        - assign a new key to these identity providers
        - remove old identity provider key

        For more details, please refer to the original issue.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example1 = okta.idp.SamlKey("example_1", x5cs=[example["certificate"]])
        example2 = okta.idp.SamlKey("example_2", x5cs=[\"\"\"MIIDnjCCAoagAwIBAgIGAVG3MN+PMA0GCSqGSIb3DQEBBQUAMIGPMQswCQYDVQQGEwJVUzETMBEGA1UECAwKQ2FsaWZvcm5p
        YTEWMBQGA1UEBwwNU2FuIEZyYW5jaXNjbzENMAsGA1UECgwET2t0YTEUMBIGA1UECwwLU1NPUHJvdmlkZXIxEDAOBgNVBAMM
        B2V4YW1wbGUxHDAaBgkqhkiG9w0BCQEWDWluZm9Ab2t0YS5jb20wHhcNMTUxMjE4MjIyMjMyWhcNMjUxMjE4MjIyMzMyWjCB
        jzELMAkGA1UEBhMCVVMxEzARBgNVBAgMCkNhbGlmb3JuaWExFjAUBgNVBAcMDVNhbiBGcmFuY2lzY28xDTALBgNVBAoMBE9r
        dGExFDASBgNVBAsMC1NTT1Byb3ZpZGVyMRAwDgYDVQQDDAdleGFtcGxlMRwwGgYJKoZIhvcNAQkBFg1pbmZvQG9rdGEuY29t
        MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtcnyvuVCrsFEKCwHDenS3Ocjed8eWDv3zLtD2K/iZfE8BMj2wpTf
        n6Ry8zCYey3mWlKdxIybnV9amrujGRnE0ab6Q16v9D6RlFQLOG6dwqoRKuZy33Uyg8PGdEudZjGbWuKCqqXEp+UKALJHV+k4
        wWeVH8g5d1n3KyR2TVajVJpCrPhLFmq1Il4G/IUnPe4MvjXqB6CpKkog1+ThWsItPRJPAM+RweFHXq7KfChXsYE7Mmfuly8s
        DQlvBmQyxZnFHVuiPfCvGHJjpvHy11YlHdOjfgqHRvZbmo30+y0X/oY/yV4YEJ00LL6eJWU4wi7ViY3HP6/VCdRjHoRdr5L/
        DwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCzzhOFkvyYLNFj2WDcq1YqD4sBy1iCia9QpRH3rjQvMKDwQDYWbi6EdOX0TQ/I
        YR7UWGj+2pXd6v0t33lYtoKocp/4lUvT3tfBnWZ5KnObi+J2uY2teUqoYkASN7F+GRPVOuMVoVgm05ss8tuMb2dLc9vsx93s
        Dt+XlMTv/2qi5VPwaDtqduKkzwW9lUfn4xIMkTiVvCpe0X2HneD2Bpuao3/U8Rk0uiPfq6TooWaoW3kjsmErhEAs9bA7xuqo
        1KKY9CdHcFhkSsMhoeaZylZHtzbnoipUlQKSLMdJQiiYZQ0bYL83/Ta9fulr1EERICMFt3GUmtYaZZKHpWSfdJp9\"\"\"])
        ```

        ## Import

        ```sh
        $ pulumi import okta:idp/samlKey:SamlKey example <key_id>
        ```


        :param str resource_name: The name of the resource.
        :param SamlKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SamlKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 x5cs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SamlKeyArgs.__new__(SamlKeyArgs)

            if x5cs is None and not opts.urn:
                raise TypeError("Missing required property 'x5cs'")
            __props__.__dict__["x5cs"] = x5cs
            __props__.__dict__["created"] = None
            __props__.__dict__["expires_at"] = None
            __props__.__dict__["kid"] = None
            __props__.__dict__["kty"] = None
            __props__.__dict__["use"] = None
            __props__.__dict__["x5t_s256"] = None
        super(SamlKey, __self__).__init__(
            'okta:idp/samlKey:SamlKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created: Optional[pulumi.Input[_builtins.str]] = None,
            expires_at: Optional[pulumi.Input[_builtins.str]] = None,
            kid: Optional[pulumi.Input[_builtins.str]] = None,
            kty: Optional[pulumi.Input[_builtins.str]] = None,
            use: Optional[pulumi.Input[_builtins.str]] = None,
            x5cs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            x5t_s256: Optional[pulumi.Input[_builtins.str]] = None) -> 'SamlKey':
        """
        Get an existing SamlKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created: Date created.
        :param pulumi.Input[_builtins.str] expires_at: Date the cert expires.
        :param pulumi.Input[_builtins.str] kid: Key ID.
        :param pulumi.Input[_builtins.str] kty: Identifies the cryptographic algorithm family used with the key.
        :param pulumi.Input[_builtins.str] use: Intended use of the public key.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] x5cs: base64-encoded X.509 certificate chain with DER encoding
        :param pulumi.Input[_builtins.str] x5t_s256: base64url-encoded SHA-256 thumbprint of the DER encoding of an X.509 certificate.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SamlKeyState.__new__(_SamlKeyState)

        __props__.__dict__["created"] = created
        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["kid"] = kid
        __props__.__dict__["kty"] = kty
        __props__.__dict__["use"] = use
        __props__.__dict__["x5cs"] = x5cs
        __props__.__dict__["x5t_s256"] = x5t_s256
        return SamlKey(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.str]:
        """
        Date created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[_builtins.str]:
        """
        Date the cert expires.
        """
        return pulumi.get(self, "expires_at")

    @_builtins.property
    @pulumi.getter
    def kid(self) -> pulumi.Output[_builtins.str]:
        """
        Key ID.
        """
        return pulumi.get(self, "kid")

    @_builtins.property
    @pulumi.getter
    def kty(self) -> pulumi.Output[_builtins.str]:
        """
        Identifies the cryptographic algorithm family used with the key.
        """
        return pulumi.get(self, "kty")

    @_builtins.property
    @pulumi.getter
    def use(self) -> pulumi.Output[_builtins.str]:
        """
        Intended use of the public key.
        """
        return pulumi.get(self, "use")

    @_builtins.property
    @pulumi.getter
    def x5cs(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        base64-encoded X.509 certificate chain with DER encoding
        """
        return pulumi.get(self, "x5cs")

    @_builtins.property
    @pulumi.getter(name="x5tS256")
    def x5t_s256(self) -> pulumi.Output[_builtins.str]:
        """
        base64url-encoded SHA-256 thumbprint of the DER encoding of an X.509 certificate.
        """
        return pulumi.get(self, "x5t_s256")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ApiTokenArgs', 'ApiToken']

@pulumi.input_type
class ApiTokenArgs:
    def __init__(__self__, *,
                 id_property: pulumi.Input[_builtins.str],
                 client_name: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network: Optional[pulumi.Input['ApiTokenNetworkArgs']] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ApiToken resource.

        :param pulumi.Input[_builtins.str] id_property: The ID of the API token.
        :param pulumi.Input[_builtins.str] client_name: The name of the API token client.
        :param pulumi.Input[_builtins.str] created: The date and time the API token was created.
        :param pulumi.Input[_builtins.str] name: The name of the API token.
        :param pulumi.Input['ApiTokenNetworkArgs'] network: The Network Condition of the API Token.
        :param pulumi.Input[_builtins.str] user_id: The userId of the user who created the API Token.
        """
        pulumi.set(__self__, "id_property", id_property)
        if client_name is not None:
            pulumi.set(__self__, "client_name", client_name)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network is not None:
            pulumi.set(__self__, "network", network)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the API token.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter(name="clientName")
    def client_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the API token client.
        """
        return pulumi.get(self, "client_name")

    @client_name.setter
    def client_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_name", value)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time the API token was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the API token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def network(self) -> Optional[pulumi.Input['ApiTokenNetworkArgs']]:
        """
        The Network Condition of the API Token.
        """
        return pulumi.get(self, "network")

    @network.setter
    def network(self, value: Optional[pulumi.Input['ApiTokenNetworkArgs']]):
        pulumi.set(self, "network", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The userId of the user who created the API Token.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _ApiTokenState:
    def __init__(__self__, *,
                 client_name: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network: Optional[pulumi.Input['ApiTokenNetworkArgs']] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ApiToken resources.

        :param pulumi.Input[_builtins.str] client_name: The name of the API token client.
        :param pulumi.Input[_builtins.str] created: The date and time the API token was created.
        :param pulumi.Input[_builtins.str] id_property: The ID of the API token.
        :param pulumi.Input[_builtins.str] name: The name of the API token.
        :param pulumi.Input['ApiTokenNetworkArgs'] network: The Network Condition of the API Token.
        :param pulumi.Input[_builtins.str] user_id: The userId of the user who created the API Token.
        """
        if client_name is not None:
            pulumi.set(__self__, "client_name", client_name)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if id_property is not None:
            pulumi.set(__self__, "id_property", id_property)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network is not None:
            pulumi.set(__self__, "network", network)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="clientName")
    def client_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the API token client.
        """
        return pulumi.get(self, "client_name")

    @client_name.setter
    def client_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_name", value)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time the API token was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the API token.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the API token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def network(self) -> Optional[pulumi.Input['ApiTokenNetworkArgs']]:
        """
        The Network Condition of the API Token.
        """
        return pulumi.get(self, "network")

    @network.setter
    def network(self, value: Optional[pulumi.Input['ApiTokenNetworkArgs']]):
        pulumi.set(self, "network", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The userId of the user who created the API Token.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("okta:index/apiToken:ApiToken")
class ApiToken(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_name: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network: Optional[pulumi.Input[Union['ApiTokenNetworkArgs', 'ApiTokenNetworkArgsDict']]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages an Okta API token configuration. This resource allows you to import and manage existing API tokens, including their network restrictions. API tokens are used to authenticate API requests to your Okta organization.

        > NOTE: This resource is import-only. API tokens cannot be created through Terraform as they are generated through the Okta Admin Console or API. You can only import existing tokens and manage their configuration.

        > WARNING: When this resource is destroyed, the API token will be revoked and can no longer be used for authentication.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.ApiToken("example",
            id_property="00T1fxzubpqiepH11d38",
            name="token-api-token-test",
            user_id="00unkw1sfbTw08c0g1d7",
            network={
                "connection": "ZONE",
                "excludes": ["nzonkw1sfwwi79Hat2d7"],
            },
            client_name="Okta API")
        ```

        ## Nested Schema for network

        ### Optional:
        - `connection` (String) The connection type of the Network Condition.

        ### Blocks:
        - `exclude` (List of String) List of excluded network zones.
        - `include` (List of String) List of included network zones.

        ### Import
        API tokens can be imported using their ID:


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] client_name: The name of the API token client.
        :param pulumi.Input[_builtins.str] created: The date and time the API token was created.
        :param pulumi.Input[_builtins.str] id_property: The ID of the API token.
        :param pulumi.Input[_builtins.str] name: The name of the API token.
        :param pulumi.Input[Union['ApiTokenNetworkArgs', 'ApiTokenNetworkArgsDict']] network: The Network Condition of the API Token.
        :param pulumi.Input[_builtins.str] user_id: The userId of the user who created the API Token.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApiTokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an Okta API token configuration. This resource allows you to import and manage existing API tokens, including their network restrictions. API tokens are used to authenticate API requests to your Okta organization.

        > NOTE: This resource is import-only. API tokens cannot be created through Terraform as they are generated through the Okta Admin Console or API. You can only import existing tokens and manage their configuration.

        > WARNING: When this resource is destroyed, the API token will be revoked and can no longer be used for authentication.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.ApiToken("example",
            id_property="00T1fxzubpqiepH11d38",
            name="token-api-token-test",
            user_id="00unkw1sfbTw08c0g1d7",
            network={
                "connection": "ZONE",
                "excludes": ["nzonkw1sfwwi79Hat2d7"],
            },
            client_name="Okta API")
        ```

        ## Nested Schema for network

        ### Optional:
        - `connection` (String) The connection type of the Network Condition.

        ### Blocks:
        - `exclude` (List of String) List of excluded network zones.
        - `include` (List of String) List of included network zones.

        ### Import
        API tokens can be imported using their ID:


        :param str resource_name: The name of the resource.
        :param ApiTokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApiTokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_name: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network: Optional[pulumi.Input[Union['ApiTokenNetworkArgs', 'ApiTokenNetworkArgsDict']]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApiTokenArgs.__new__(ApiTokenArgs)

            __props__.__dict__["client_name"] = client_name
            __props__.__dict__["created"] = created
            if id_property is None and not opts.urn:
                raise TypeError("Missing required property 'id_property'")
            __props__.__dict__["id_property"] = id_property
            __props__.__dict__["name"] = name
            __props__.__dict__["network"] = network
            __props__.__dict__["user_id"] = user_id
        super(ApiToken, __self__).__init__(
            'okta:index/apiToken:ApiToken',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            client_name: Optional[pulumi.Input[_builtins.str]] = None,
            created: Optional[pulumi.Input[_builtins.str]] = None,
            id_property: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            network: Optional[pulumi.Input[Union['ApiTokenNetworkArgs', 'ApiTokenNetworkArgsDict']]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'ApiToken':
        """
        Get an existing ApiToken resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] client_name: The name of the API token client.
        :param pulumi.Input[_builtins.str] created: The date and time the API token was created.
        :param pulumi.Input[_builtins.str] id_property: The ID of the API token.
        :param pulumi.Input[_builtins.str] name: The name of the API token.
        :param pulumi.Input[Union['ApiTokenNetworkArgs', 'ApiTokenNetworkArgsDict']] network: The Network Condition of the API Token.
        :param pulumi.Input[_builtins.str] user_id: The userId of the user who created the API Token.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApiTokenState.__new__(_ApiTokenState)

        __props__.__dict__["client_name"] = client_name
        __props__.__dict__["created"] = created
        __props__.__dict__["id_property"] = id_property
        __props__.__dict__["name"] = name
        __props__.__dict__["network"] = network
        __props__.__dict__["user_id"] = user_id
        return ApiToken(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clientName")
    def client_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the API token client.
        """
        return pulumi.get(self, "client_name")

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time the API token was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the API token.
        """
        return pulumi.get(self, "id_property")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the API token.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def network(self) -> pulumi.Output[Optional['outputs.ApiTokenNetwork']]:
        """
        The Network Condition of the API Token.
        """
        return pulumi.get(self, "network")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[_builtins.str]:
        """
        The userId of the user who created the API Token.
        """
        return pulumi.get(self, "user_id")

